@@ -26,7 +26,7 @@
 #include <bonobo/bonobo-exception.h>
 #include "gnome-db-i18n.h"
 #include <gconf/gconf.h>
-#include <libgda/gda-log.h>
+#include <libgda/gda-data-model-array.h>
 #include <libgnomedb/gnome-db-config.h>
 
 static GList *
@@ -186,6 +186,60 @@ gnome_db_config_get_component_list (const gchar *query)
 	return list;
 }
 
+/**
+ * gnome_db_config_get_component_data_model
+ * @query: condition for components to be retrieved.
+ *
+ * Return a list of all components currently installed in
+ * the system that match the given query (see
+ * BonoboActivation documentation).
+ *
+ * Returns: a #GdaDataModel object, or %NULL on failure.
+ */
+GdaDataModel *
+gnome_db_config_get_component_data_model (const gchar *query)
+{
+	GdaDataModel *model;
+	GList *list, *i;
+	
+	list = gnome_db_config_get_component_list (query);
+	g_return_val_if_fail (list != NULL, NULL);
+
+	model = gda_data_model_array_new (6);
+	gda_data_model_set_column_title (model, 0, _("ID"));
+	gda_data_model_set_column_title (model, 1, _("Location"));
+	gda_data_model_set_column_title (model, 2, _("Description"));
+	gda_data_model_set_column_title (model, 3, _("Username"));
+	gda_data_model_set_column_title (model, 4, _("Hostname"));
+	gda_data_model_set_column_title (model, 5, _("Domain"));
+	
+	for (i = list; i != NULL; i = i->next) {
+		GnomeDbComponentInfo *info;
+		GList *row = NULL;
+		
+		info = (GnomeDbComponentInfo *) i->data;
+		row = g_list_append (row,
+				     gda_value_new_string (info->id));
+		row = g_list_append (row,
+				     gda_value_new_string (info->location));
+		row = g_list_append (row,
+				     gda_value_new_string (info->description));
+		row = g_list_append (row,
+				     gda_value_new_string (info->username));
+		row = g_list_append (row,
+				     gda_value_new_string (info->hostname));
+		row = g_list_append (row,
+				     gda_value_new_string (info->domain));
+
+		gda_data_model_append_row (GDA_DATA_MODEL (model), row);
+	}
+	
+	/* free memory */
+	gnome_db_config_free_component_list (list);
+
+	return model;
+}
+
 /**
  * gnome_db_config_free_component_list
  */
